==> zio-aws-iot1clickprojects_2.13-5.17.157.1-sources.jar: zio/aws/iot1clickprojects/model/CreatePlacementRequest.scala <==
package zio.aws.iot1clickprojects.model
import zio.aws.iot1clickprojects.model.primitives.{
  AttributeValue,
  AttributeName,
  ProjectName,
  PlacementName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreatePlacementRequest(
    placementName: PlacementName,
    projectName: ProjectName,
    attributes: Option[Map[AttributeName, AttributeValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest = {
    import CreatePlacementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
      .builder()
      .placementName(PlacementName.unwrap(placementName): java.lang.String)
      .projectName(ProjectName.unwrap(projectName): java.lang.String)
      .optionallyWith(
        attributes.map(value =>
          value
            .map({ case (key, value) =>
              (AttributeName.unwrap(key): java.lang.String) -> (AttributeValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.attributes)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickprojects.model.CreatePlacementRequest.ReadOnly =
    zio.aws.iot1clickprojects.model.CreatePlacementRequest.wrap(buildAwsValue())
}
object CreatePlacementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickprojects.model.CreatePlacementRequest =
      zio.aws.iot1clickprojects.model.CreatePlacementRequest(
        placementName,
        projectName,
        attributes.map(value => value)
      )
    def placementName: PlacementName
    def projectName: ProjectName
    def attributes: Option[Map[AttributeName, AttributeValue]]
    def getPlacementName: ZIO[Any, Nothing, PlacementName] =
      ZIO.succeed(placementName)
    def getProjectName: ZIO[Any, Nothing, ProjectName] =
      ZIO.succeed(projectName)
    def getAttributes: ZIO[Any, AwsError, Map[AttributeName, AttributeValue]] =
      AwsError.unwrapOptionField("attributes", attributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
  ) extends zio.aws.iot1clickprojects.model.CreatePlacementRequest.ReadOnly {
    override val placementName: PlacementName =
      zio.aws.iot1clickprojects.model.primitives
        .PlacementName(impl.placementName())
    override val projectName: ProjectName =
      zio.aws.iot1clickprojects.model.primitives.ProjectName(impl.projectName())
    override val attributes: Option[Map[AttributeName, AttributeValue]] = scala
      .Option(impl.attributes())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.iot1clickprojects.model.primitives
              .AttributeName(key) -> zio.aws.iot1clickprojects.model.primitives
              .AttributeValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
  ): zio.aws.iot1clickprojects.model.CreatePlacementRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickprojects_2.13-5.17.267.4-sources.jar: zio/aws/iot1clickprojects/model/CreatePlacementRequest.scala <==
package zio.aws.iot1clickprojects.model
import zio.aws.iot1clickprojects.model.primitives.{
  AttributeValue,
  AttributeName,
  ProjectName,
  PlacementName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreatePlacementRequest(
    placementName: PlacementName,
    projectName: ProjectName,
    attributes: Optional[Map[AttributeName, AttributeValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest = {
    import CreatePlacementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
      .builder()
      .placementName(PlacementName.unwrap(placementName): java.lang.String)
      .projectName(ProjectName.unwrap(projectName): java.lang.String)
      .optionallyWith(
        attributes.map(value =>
          value
            .map({ case (key, value) =>
              (AttributeName.unwrap(key): java.lang.String) -> (AttributeValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.attributes)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickprojects.model.CreatePlacementRequest.ReadOnly =
    zio.aws.iot1clickprojects.model.CreatePlacementRequest.wrap(buildAwsValue())
}
object CreatePlacementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickprojects.model.CreatePlacementRequest =
      zio.aws.iot1clickprojects.model.CreatePlacementRequest(
        placementName,
        projectName,
        attributes.map(value => value)
      )
    def placementName: PlacementName
    def projectName: ProjectName
    def attributes: Optional[Map[AttributeName, AttributeValue]]
    def getPlacementName: ZIO[Any, Nothing, PlacementName] =
      ZIO.succeed(placementName)
    def getProjectName: ZIO[Any, Nothing, ProjectName] =
      ZIO.succeed(projectName)
    def getAttributes: ZIO[Any, AwsError, Map[AttributeName, AttributeValue]] =
      AwsError.unwrapOptionField("attributes", attributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
  ) extends zio.aws.iot1clickprojects.model.CreatePlacementRequest.ReadOnly {
    override val placementName: PlacementName =
      zio.aws.iot1clickprojects.model.primitives
        .PlacementName(impl.placementName())
    override val projectName: ProjectName =
      zio.aws.iot1clickprojects.model.primitives.ProjectName(impl.projectName())
    override val attributes: Optional[Map[AttributeName, AttributeValue]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.attributes())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.iot1clickprojects.model.primitives.AttributeName(
                key
              ) -> zio.aws.iot1clickprojects.model.primitives
                .AttributeValue(value)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickprojects.model.CreatePlacementRequest
  ): zio.aws.iot1clickprojects.model.CreatePlacementRequest.ReadOnly =
    new Wrapper(impl)
}
